pub struct CondaSyncMessage {
pub connect: PortRef<Connect>,
pub result: PortRef<Result<CondaSyncResult, String>>,
pub workspace: WorkspaceLocation,
pub path_prefix_replacements: HashMap<PathBuf, WorkspaceLocation>,
}Fields
connect: PortRef<Connect>The connect message to create a duplex bytestream with the client.
result: PortRef<Result<CondaSyncResult, String>>A port to send back the result or any errors.
workspace: WorkspaceLocationThe location of the workspace to sync.
path_prefix_replacements: HashMap<PathBuf, WorkspaceLocation>Path prefixes to fixup/replace when copying.